Features to add

- create artifact (build phase)
- artifacts opslaan (https://docs.gitlab.com/ee/ci/yaml/#artifacts, https://www.linode.com/docs/applications/project-management/how-to-create-a-private-python-package-repository/)
- provision env on AWS (via terraform)
- deploy to env
- multiple env
- publish unit test and code quality reports
- manual approval for prod
- web page
- smoke test
- API test
- UI test